# PBC4cip
PBC4cip is a machine learning package used to handle class imbalanced prediction problems.

## Built With

* [Pandas](https://pandas.pydata.org) - DataFrame framework
* [Numpy](https://numpy.org) - Numpy Library
* [tqdm](https://tqdm.github.io/) - Progress bar helper

## Getting Started
To have an idea on how to run the program just see the example located in PBC4cip/TestProg.py

There are various command line arguments that can be passed to the program, these can be found by running python src/PBC4cip.CLI.py --help.